You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@beehive.apache.org by cr...@apache.org on 2006/10/09 00:39:01 UTC

svn commit: r454228 - in /beehive/trunk/netui: src/pageflow/org/apache/beehive/netui/pageflow/internal/ test/webapps/drt/src/returnTo/pageWithJspInclude/ test/webapps/drt/testRecorder/config/ test/webapps/drt/testRecorder/tests/ test/webapps/drt/web/re...

Author: crogers
Date: Sun Oct  8 15:39:00 2006
New Revision: 454228

URL: http://svn.apache.org/viewvc?view=rev&rev=454228
Log:
Fix the Jpf.NavigateTo.currentPage feature to work with pages using a jsp:include, http://issues.apache.org/jira/browse/BEEHIVE-1115

Tests: NetUI BVT (WinXP pass)


Added:
    beehive/trunk/netui/test/webapps/drt/src/returnTo/pageWithJspInclude/
    beehive/trunk/netui/test/webapps/drt/src/returnTo/pageWithJspInclude/Controller.java   (with props)
    beehive/trunk/netui/test/webapps/drt/src/returnTo/pageWithJspInclude/SharedFlow.java   (with props)
    beehive/trunk/netui/test/webapps/drt/testRecorder/tests/ReturnToWithInclude.xml   (with props)
    beehive/trunk/netui/test/webapps/drt/web/returnTo/pageWithJspInclude/
    beehive/trunk/netui/test/webapps/drt/web/returnTo/pageWithJspInclude/index.jsp   (with props)
    beehive/trunk/netui/test/webapps/drt/web/returnTo/pageWithJspInclude/message.jsp   (with props)
    beehive/trunk/netui/test/webapps/drt/web/returnTo/pageWithJspInclude/page1.jsp   (with props)
    beehive/trunk/netui/test/webapps/drt/web/returnTo/pageWithJspInclude/page2.jsp   (with props)
Modified:
    beehive/trunk/netui/src/pageflow/org/apache/beehive/netui/pageflow/internal/DefaultActionForwardHandler.java
    beehive/trunk/netui/src/pageflow/org/apache/beehive/netui/pageflow/internal/InternalConstants.java
    beehive/trunk/netui/test/webapps/drt/testRecorder/config/testRecorder-tests.xml

Modified: beehive/trunk/netui/src/pageflow/org/apache/beehive/netui/pageflow/internal/DefaultActionForwardHandler.java
URL: http://svn.apache.org/viewvc/beehive/trunk/netui/src/pageflow/org/apache/beehive/netui/pageflow/internal/DefaultActionForwardHandler.java?view=diff&rev=454228&r1=454227&r2=454228
==============================================================================
--- beehive/trunk/netui/src/pageflow/org/apache/beehive/netui/pageflow/internal/InternalConstants.java (original)
+++ beehive/trunk/netui/src/pageflow/org/apache/beehive/netui/pageflow/internal/InternalConstants.java Sun Oct  8 15:39:00 2006
@@ -55,6 +55,7 @@
     public static final String CURRENT_JPF_ATTR = ATTR_PREFIX + "curPageFlow";
     public static final String CURRENT_LONGLIVED_ATTR = ATTR_PREFIX + "curLongLivedModule";
     public static final String SHARED_FLOW_ATTR_PREFIX = ATTR_PREFIX + "sharedFlow:";
+    public static final String SAVED_PREVIOUS_PAGE_INFO_ATTR = ATTR_PREFIX + "savedPrevPageInfo";
 
     public static final String NETUI_CONFIG_PATH = "/WEB-INF/beehive-netui-config.xml";
     

Added: beehive/trunk/netui/test/webapps/drt/src/returnTo/pageWithJspInclude/Controller.java
URL: http://svn.apache.org/viewvc/beehive/trunk/netui/test/webapps/drt/src/returnTo/pageWithJspInclude/Controller.java?view=auto&rev=454228
==============================================================================
--- beehive/trunk/netui/test/webapps/drt/src/returnTo/pageWithJspInclude/Controller.java (added)
+++ beehive/trunk/netui/test/webapps/drt/src/returnTo/pageWithJspInclude/Controller.java Sun Oct  8 15:39:00 2006
@@ -0,0 +1,58 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ * 
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ * $Header:$
+ */
+package returnTo.pageWithJspInclude;
+
+import org.apache.beehive.netui.pageflow.Forward;
+import org.apache.beehive.netui.pageflow.PageFlowController;
+import org.apache.beehive.netui.pageflow.annotations.Jpf;
+
+@Jpf.Controller(
+    simpleActions = {
+        @Jpf.SimpleAction(name = "begin", path = "index.jsp"),
+        @Jpf.SimpleAction(name = "page1", path = "page1.jsp"),
+        @Jpf.SimpleAction(name = "page2", path = "page2.jsp")
+    },
+    sharedFlowRefs={
+        @Jpf.SharedFlowRef(name="shared", type=SharedFlow.class)
+    }
+)
+public class Controller extends PageFlowController
+{
+    @Jpf.Action(forwards = {
+        @Jpf.Forward(name = "prevPage",
+                     navigateTo = Jpf.NavigateTo.previousPage)
+        }
+    )
+    protected Forward returnToPrevPage() {
+        Forward forward = new Forward("prevPage");
+        forward.addActionOutput("message","in " + getDisplayName() + ".returnToPrevPage()");
+        return forward;
+    }
+
+    @Jpf.Action(forwards = {
+        @Jpf.Forward(name = "currentPage",
+                     navigateTo = Jpf.NavigateTo.currentPage)
+        }
+    )
+    protected Forward returnToPage() {
+        Forward forward = new Forward("currentPage");
+        forward.addActionOutput("message","in " + getDisplayName() + ".returnToPage()");
+        return forward;
+    }
+}

Propchange: beehive/trunk/netui/test/webapps/drt/src/returnTo/pageWithJspInclude/Controller.java
------------------------------------------------------------------------------
    svn:eol-style = native

Added: beehive/trunk/netui/test/webapps/drt/src/returnTo/pageWithJspInclude/SharedFlow.java
URL: http://svn.apache.org/viewvc/beehive/trunk/netui/test/webapps/drt/src/returnTo/pageWithJspInclude/SharedFlow.java?view=auto&rev=454228
==============================================================================
--- beehive/trunk/netui/test/webapps/drt/src/returnTo/pageWithJspInclude/SharedFlow.java (added)
+++ beehive/trunk/netui/test/webapps/drt/src/returnTo/pageWithJspInclude/SharedFlow.java Sun Oct  8 15:39:00 2006
@@ -0,0 +1,49 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ * $Header:$
+ */
+package returnTo.pageWithJspInclude;
+
+import org.apache.beehive.netui.pageflow.Forward;
+import org.apache.beehive.netui.pageflow.SharedFlowController;
+import org.apache.beehive.netui.pageflow.annotations.Jpf;
+
+@Jpf.Controller()
+public class SharedFlow extends SharedFlowController
+{
+    @Jpf.Action(forwards = {
+        @Jpf.Forward(name = "prevPage",
+                     navigateTo = Jpf.NavigateTo.previousPage)
+        }
+    )
+    protected Forward returnToPrevPage() {
+        Forward forward = new Forward("prevPage");
+        forward.addActionOutput("message","in " + getDisplayName() + ".returnToPrevPage()");
+        return forward;
+    }
+
+    @Jpf.Action(forwards = {
+        @Jpf.Forward(name = "currentPage",
+                     navigateTo = Jpf.NavigateTo.currentPage)
+        }
+    )
+    protected Forward returnToPage() {
+        Forward forward = new Forward("currentPage");
+        forward.addActionOutput("message","in " + getDisplayName() + ".returnToPage()");
+        return forward;
+    }
+}

Propchange: beehive/trunk/netui/test/webapps/drt/src/returnTo/pageWithJspInclude/SharedFlow.java
------------------------------------------------------------------------------
    svn:eol-style = native

Modified: beehive/trunk/netui/test/webapps/drt/testRecorder/config/testRecorder-tests.xml
URL: http://svn.apache.org/viewvc/beehive/trunk/netui/test/webapps/drt/testRecorder/config/testRecorder-tests.xml?view=diff&rev=454228&r1=454227&r2=454228
==============================================================================
--- beehive/trunk/netui/test/webapps/drt/testRecorder/config/testRecorder-tests.xml (original)
+++ beehive/trunk/netui/test/webapps/drt/testRecorder/config/testRecorder-tests.xml Sun Oct  8 15:39:00 2006
@@ -7065,6 +7065,20 @@
          </categories>
       </test>
       <test>
+         <name>ReturnToWithInclude</name>
+         <description>Tests the NavigateTo feature with a page containing a jsp:include to make sure we don't set current page info to the included page. (BEEHIVE-1115)</description>
+         <webapp>coreWeb</webapp>
+         <categories>
+            <category>bvt</category>
+            <category>bvt.struts11</category>
+            <category>jiraBugs</category>
+         </categories>
+         <features>
+            <feature>PageFlow</feature>
+            <feature>NavigateTo</feature>
+         </features>
+      </test>
+      <test>
          <name>RewriteNameVar</name>
          <description>Verify that the resultID attribute.</description>
          <webapp>coreWeb</webapp>

Added: beehive/trunk/netui/test/webapps/drt/testRecorder/tests/ReturnToWithInclude.xml
URL: http://svn.apache.org/viewvc/beehive/trunk/netui/test/webapps/drt/testRecorder/tests/ReturnToWithInclude.xml?view=auto&rev=454228
==============================================================================
--- beehive/trunk/netui/test/webapps/drt/testRecorder/tests/ReturnToWithInclude.xml (added)
+++ beehive/trunk/netui/test/webapps/drt/testRecorder/tests/ReturnToWithInclude.xml Sun Oct  8 15:39:00 2006
@@ -0,0 +1,1171 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<recorderSession xmlns="http://beehive.apache.org/netui/tools/testrecorder/2004/session">
+<sessionName>ReturnToWithInclude</sessionName>
+<tester>crogers</tester>
+<startDate>08 Oct 2006, 03:59:48.140 PM MDT</startDate>
+<description>Tests the NavigateTo feature with a page containing a jsp:include to make sure we don't set current page info to the included page. (BEEHIVE-1115)</description>
+<tests>
+<test>
+<testNumber>1</testNumber>
+<request>
+<protocol>HTTP</protocol>
+<protocolVersion>1.1</protocolVersion>
+<host>localhost</host>
+<port>8080</port>
+<uri>/coreWeb/returnTo/pageWithJspInclude/begin.do</uri>
+<method>GET</method>
+<parameters>
+</parameters>
+<cookies>
+<cookie>
+<name>JSESSIONID</name>
+<value>E07C1635C4C5C0250C2B98619EC403EC</value>
+</cookie>
+</cookies>
+<headers>
+<header>
+<name>accept</name>
+<value>text/xml,application/xml,application/xhtml+xml,text/html;q=0.9,text/plain;q=0.8,image/png,*/*;q=0.5</value>
+</header>
+<header>
+<name>accept-charset</name>
+<value>UTF-8,*</value>
+</header>
+<header>
+<name>accept-encoding</name>
+<value>gzip,deflate</value>
+</header>
+<header>
+<name>accept-language</name>
+<value>en-us,en;q=0.5</value>
+</header>
+<header>
+<name>connection</name>
+<value>keep-alive</value>
+</header>
+<header>
+<name>cookie</name>
+<value>JSESSIONID=E07C1635C4C5C0250C2B98619EC403EC</value>
+</header>
+<header>
+<name>host</name>
+<value>localhost:8080</value>
+</header>
+<header>
+<name>keep-alive</name>
+<value>300</value>
+</header>
+<header>
+<name>user-agent</name>
+<value>Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.7) Gecko/20060909 Firefox/1.5.0.7</value>
+</header>
+</headers>
+</request>
+<response>
+<statusCode>200</statusCode>
+<reason></reason>
+<responseBody>
+<![CDATA[<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"
+	"http://www.w3.org/TR/html4/loose.dtd">
+<html lang="en">
+
+    <head>
+        <title>NavigateTo Current/Previous JSP with &lt;jsp:include&gt;</title>
+        <base href="http://localhost:8080/coreWeb/returnTo/pageWithJspInclude/index.jsp">
+    </head>
+    <body>
+        <h3>NavigateTo Current/Previous JSP with &lt;jsp:include&gt;</h3>
+        <p>
+            Tests the NavigateTo feature with a page containing a
+            &lt;jsp:include&gt; to make sure we don't set current page
+            info to the included page. (BEEHIVE-1115)
+        </p>
+        <br/>
+        <p>Start the test by going to the first JSP.</p>
+        <br/><br/>
+        <a href="/coreWeb/returnTo/pageWithJspInclude/page1.do">page one...</a>
+    </body>
+
+</html>]]>
+</responseBody>
+</response>
+</test>
+<test>
+<testNumber>2</testNumber>
+<request>
+<protocol>HTTP</protocol>
+<protocolVersion>1.1</protocolVersion>
+<host>localhost</host>
+<port>8080</port>
+<uri>/coreWeb/returnTo/pageWithJspInclude/page1.do</uri>
+<method>GET</method>
+<parameters>
+</parameters>
+<cookies>
+<cookie>
+<name>JSESSIONID</name>
+<value>E07C1635C4C5C0250C2B98619EC403EC</value>
+</cookie>
+</cookies>
+<headers>
+<header>
+<name>accept</name>
+<value>text/xml,application/xml,application/xhtml+xml,text/html;q=0.9,text/plain;q=0.8,image/png,*/*;q=0.5</value>
+</header>
+<header>
+<name>accept-charset</name>
+<value>UTF-8,*</value>
+</header>
+<header>
+<name>accept-encoding</name>
+<value>gzip,deflate</value>
+</header>
+<header>
+<name>accept-language</name>
+<value>en-us,en;q=0.5</value>
+</header>
+<header>
+<name>connection</name>
+<value>keep-alive</value>
+</header>
+<header>
+<name>cookie</name>
+<value>JSESSIONID=E07C1635C4C5C0250C2B98619EC403EC</value>
+</header>
+<header>
+<name>host</name>
+<value>localhost:8080</value>
+</header>
+<header>
+<name>keep-alive</name>
+<value>300</value>
+</header>
+<header>
+<name>referer</name>
+<value>http://localhost:8080/coreWeb/returnTo/pageWithJspInclude/begin.do</value>
+</header>
+<header>
+<name>user-agent</name>
+<value>Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.7) Gecko/20060909 Firefox/1.5.0.7</value>
+</header>
+</headers>
+</request>
+<response>
+<statusCode>200</statusCode>
+<reason></reason>
+<responseBody>
+<![CDATA[<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"
+	"http://www.w3.org/TR/html4/loose.dtd">
+<html lang="en">
+
+    <head>
+        <title>NavigateTo Current/Previous JSP with &lt;jsp:include&gt;</title>
+        <base href="http://localhost:8080/coreWeb/returnTo/pageWithJspInclude/page1.jsp">
+    </head>
+    <body>
+        <h3>NavigateTo Current/Previous JSP with &lt;jsp:include&gt;</h3>
+        <h3>Page1.jsp</h3>
+
+        <p>
+            Tests the NavigateTo feature with a page containing a
+            &lt;jsp:include&gt; to make sure we don't set current page
+            info to the included page. (BEEHIVE-1115)
+        </p>
+
+        <br/><br/>&quot;NavigateTo&quot; this page:
+        <a href="/coreWeb/returnTo/pageWithJspInclude/returnToPage.do">current...</a>
+
+        <br/><br/>&quot;NavigateTo&quot; the previous page:
+        <a href="/coreWeb/returnTo/pageWithJspInclude/returnToPrevPage.do">Prev...</a>
+
+        <br/><br/>Now, test &quot;NavigateTo&quot; this page (via shared flow):
+        <a href="/coreWeb/returnTo/pageWithJspInclude/shared.returnToPage.do">shared.curr</a>
+
+        <br/><br/>Now, test &quot;NavigateTo&quot; the previous page (via shared flow):
+        <a href="/coreWeb/returnTo/pageWithJspInclude/shared.returnToPrevPage.do">shared.prev</a>
+
+        <br/>
+        
+
+
+
+message = <span></span>
+
+
+
+
+        <br/><br/>go to
+        <a href="/coreWeb/returnTo/pageWithJspInclude/page2.do">page two...</a>
+    </body>
+
+</html>]]>
+</responseBody>
+</response>
+</test>
+<test>
+<testNumber>3</testNumber>
+<request>
+<protocol>HTTP</protocol>
+<protocolVersion>1.1</protocolVersion>
+<host>localhost</host>
+<port>8080</port>
+<uri>/coreWeb/returnTo/pageWithJspInclude/returnToPage.do</uri>
+<method>GET</method>
+<parameters>
+</parameters>
+<cookies>
+<cookie>
+<name>JSESSIONID</name>
+<value>E07C1635C4C5C0250C2B98619EC403EC</value>
+</cookie>
+</cookies>
+<headers>
+<header>
+<name>accept</name>
+<value>text/xml,application/xml,application/xhtml+xml,text/html;q=0.9,text/plain;q=0.8,image/png,*/*;q=0.5</value>
+</header>
+<header>
+<name>accept-charset</name>
+<value>UTF-8,*</value>
+</header>
+<header>
+<name>accept-encoding</name>
+<value>gzip,deflate</value>
+</header>
+<header>
+<name>accept-language</name>
+<value>en-us,en;q=0.5</value>
+</header>
+<header>
+<name>connection</name>
+<value>keep-alive</value>
+</header>
+<header>
+<name>cookie</name>
+<value>JSESSIONID=E07C1635C4C5C0250C2B98619EC403EC</value>
+</header>
+<header>
+<name>host</name>
+<value>localhost:8080</value>
+</header>
+<header>
+<name>keep-alive</name>
+<value>300</value>
+</header>
+<header>
+<name>referer</name>
+<value>http://localhost:8080/coreWeb/returnTo/pageWithJspInclude/page1.do</value>
+</header>
+<header>
+<name>user-agent</name>
+<value>Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.7) Gecko/20060909 Firefox/1.5.0.7</value>
+</header>
+</headers>
+</request>
+<response>
+<statusCode>200</statusCode>
+<reason></reason>
+<responseBody>
+<![CDATA[<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"
+	"http://www.w3.org/TR/html4/loose.dtd">
+<html lang="en">
+
+    <head>
+        <title>NavigateTo Current/Previous JSP with &lt;jsp:include&gt;</title>
+        <base href="http://localhost:8080/coreWeb/returnTo/pageWithJspInclude/page1.jsp">
+    </head>
+    <body>
+        <h3>NavigateTo Current/Previous JSP with &lt;jsp:include&gt;</h3>
+        <h3>Page1.jsp</h3>
+
+        <p>
+            Tests the NavigateTo feature with a page containing a
+            &lt;jsp:include&gt; to make sure we don't set current page
+            info to the included page. (BEEHIVE-1115)
+        </p>
+
+        <br/><br/>&quot;NavigateTo&quot; this page:
+        <a href="/coreWeb/returnTo/pageWithJspInclude/returnToPage.do">current...</a>
+
+        <br/><br/>&quot;NavigateTo&quot; the previous page:
+        <a href="/coreWeb/returnTo/pageWithJspInclude/returnToPrevPage.do">Prev...</a>
+
+        <br/><br/>Now, test &quot;NavigateTo&quot; this page (via shared flow):
+        <a href="/coreWeb/returnTo/pageWithJspInclude/shared.returnToPage.do">shared.curr</a>
+
+        <br/><br/>Now, test &quot;NavigateTo&quot; the previous page (via shared flow):
+        <a href="/coreWeb/returnTo/pageWithJspInclude/shared.returnToPrevPage.do">shared.prev</a>
+
+        <br/>
+        
+
+
+
+message = <span>in /returnTo/pageWithJspInclude/Controller.jpf.returnToPage()</span>
+
+
+
+
+        <br/><br/>go to
+        <a href="/coreWeb/returnTo/pageWithJspInclude/page2.do">page two...</a>
+    </body>
+
+</html>]]>
+</responseBody>
+</response>
+</test>
+<test>
+<testNumber>4</testNumber>
+<request>
+<protocol>HTTP</protocol>
+<protocolVersion>1.1</protocolVersion>
+<host>localhost</host>
+<port>8080</port>
+<uri>/coreWeb/returnTo/pageWithJspInclude/shared.returnToPage.do</uri>
+<method>GET</method>
+<parameters>
+</parameters>
+<cookies>
+<cookie>
+<name>JSESSIONID</name>
+<value>E07C1635C4C5C0250C2B98619EC403EC</value>
+</cookie>
+</cookies>
+<headers>
+<header>
+<name>accept</name>
+<value>text/xml,application/xml,application/xhtml+xml,text/html;q=0.9,text/plain;q=0.8,image/png,*/*;q=0.5</value>
+</header>
+<header>
+<name>accept-charset</name>
+<value>UTF-8,*</value>
+</header>
+<header>
+<name>accept-encoding</name>
+<value>gzip,deflate</value>
+</header>
+<header>
+<name>accept-language</name>
+<value>en-us,en;q=0.5</value>
+</header>
+<header>
+<name>connection</name>
+<value>keep-alive</value>
+</header>
+<header>
+<name>cookie</name>
+<value>JSESSIONID=E07C1635C4C5C0250C2B98619EC403EC</value>
+</header>
+<header>
+<name>host</name>
+<value>localhost:8080</value>
+</header>
+<header>
+<name>keep-alive</name>
+<value>300</value>
+</header>
+<header>
+<name>referer</name>
+<value>http://localhost:8080/coreWeb/returnTo/pageWithJspInclude/returnToPage.do</value>
+</header>
+<header>
+<name>user-agent</name>
+<value>Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.7) Gecko/20060909 Firefox/1.5.0.7</value>
+</header>
+</headers>
+</request>
+<response>
+<statusCode>200</statusCode>
+<reason></reason>
+<responseBody>
+<![CDATA[<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"
+	"http://www.w3.org/TR/html4/loose.dtd">
+<html lang="en">
+
+    <head>
+        <title>NavigateTo Current/Previous JSP with &lt;jsp:include&gt;</title>
+        <base href="http://localhost:8080/coreWeb/returnTo/pageWithJspInclude/page1.jsp">
+    </head>
+    <body>
+        <h3>NavigateTo Current/Previous JSP with &lt;jsp:include&gt;</h3>
+        <h3>Page1.jsp</h3>
+
+        <p>
+            Tests the NavigateTo feature with a page containing a
+            &lt;jsp:include&gt; to make sure we don't set current page
+            info to the included page. (BEEHIVE-1115)
+        </p>
+
+        <br/><br/>&quot;NavigateTo&quot; this page:
+        <a href="/coreWeb/returnTo/pageWithJspInclude/returnToPage.do">current...</a>
+
+        <br/><br/>&quot;NavigateTo&quot; the previous page:
+        <a href="/coreWeb/returnTo/pageWithJspInclude/returnToPrevPage.do">Prev...</a>
+
+        <br/><br/>Now, test &quot;NavigateTo&quot; this page (via shared flow):
+        <a href="/coreWeb/returnTo/pageWithJspInclude/shared.returnToPage.do">shared.curr</a>
+
+        <br/><br/>Now, test &quot;NavigateTo&quot; the previous page (via shared flow):
+        <a href="/coreWeb/returnTo/pageWithJspInclude/shared.returnToPrevPage.do">shared.prev</a>
+
+        <br/>
+        
+
+
+
+message = <span>in returnTo.pageWithJspInclude.SharedFlow.returnToPage()</span>
+
+
+
+
+        <br/><br/>go to
+        <a href="/coreWeb/returnTo/pageWithJspInclude/page2.do">page two...</a>
+    </body>
+
+</html>]]>
+</responseBody>
+</response>
+</test>
+<test>
+<testNumber>5</testNumber>
+<request>
+<protocol>HTTP</protocol>
+<protocolVersion>1.1</protocolVersion>
+<host>localhost</host>
+<port>8080</port>
+<uri>/coreWeb/returnTo/pageWithJspInclude/page2.do</uri>
+<method>GET</method>
+<parameters>
+</parameters>
+<cookies>
+<cookie>
+<name>JSESSIONID</name>
+<value>E07C1635C4C5C0250C2B98619EC403EC</value>
+</cookie>
+</cookies>
+<headers>
+<header>
+<name>accept</name>
+<value>text/xml,application/xml,application/xhtml+xml,text/html;q=0.9,text/plain;q=0.8,image/png,*/*;q=0.5</value>
+</header>
+<header>
+<name>accept-charset</name>
+<value>UTF-8,*</value>
+</header>
+<header>
+<name>accept-encoding</name>
+<value>gzip,deflate</value>
+</header>
+<header>
+<name>accept-language</name>
+<value>en-us,en;q=0.5</value>
+</header>
+<header>
+<name>connection</name>
+<value>keep-alive</value>
+</header>
+<header>
+<name>cookie</name>
+<value>JSESSIONID=E07C1635C4C5C0250C2B98619EC403EC</value>
+</header>
+<header>
+<name>host</name>
+<value>localhost:8080</value>
+</header>
+<header>
+<name>keep-alive</name>
+<value>300</value>
+</header>
+<header>
+<name>referer</name>
+<value>http://localhost:8080/coreWeb/returnTo/pageWithJspInclude/shared.returnToPage.do</value>
+</header>
+<header>
+<name>user-agent</name>
+<value>Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.7) Gecko/20060909 Firefox/1.5.0.7</value>
+</header>
+</headers>
+</request>
+<response>
+<statusCode>200</statusCode>
+<reason></reason>
+<responseBody>
+<![CDATA[<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"
+	"http://www.w3.org/TR/html4/loose.dtd">
+<html lang="en">
+
+    <head>
+        <title>NavigateTo Current/Previous JSP with &lt;jsp:include&gt;</title>
+        <base href="http://localhost:8080/coreWeb/returnTo/pageWithJspInclude/page2.jsp">
+    </head>
+    <body>
+        <h3>NavigateTo Current/Previous JSP with &lt;jsp:include&gt;</h3>
+        <h3>Page2.jsp</h3>
+
+        <br/><br/>&quot;NavigateTo&quot; this page:
+        <a href="/coreWeb/returnTo/pageWithJspInclude/returnToPage.do">current...</a>
+
+        <br/><br/>&quot;NavigateTo&quot; the previous page:
+        <a href="/coreWeb/returnTo/pageWithJspInclude/returnToPrevPage.do">Prev...</a>
+
+        <br/><br/>Now, test &quot;NavigateTo&quot; this page (via shared flow):
+        <a href="/coreWeb/returnTo/pageWithJspInclude/shared.returnToPage.do">shared.curr</a>
+
+        <br/><br/>Now, test &quot;NavigateTo&quot; the previous page (via shared flow):
+        <a href="/coreWeb/returnTo/pageWithJspInclude/shared.returnToPrevPage.do">shared.prev</a>
+
+        <br/>
+        
+
+
+
+message = <span></span>
+
+
+
+    </body>
+
+</html>]]>
+</responseBody>
+</response>
+</test>
+<test>
+<testNumber>6</testNumber>
+<request>
+<protocol>HTTP</protocol>
+<protocolVersion>1.1</protocolVersion>
+<host>localhost</host>
+<port>8080</port>
+<uri>/coreWeb/returnTo/pageWithJspInclude/returnToPage.do</uri>
+<method>GET</method>
+<parameters>
+</parameters>
+<cookies>
+<cookie>
+<name>JSESSIONID</name>
+<value>E07C1635C4C5C0250C2B98619EC403EC</value>
+</cookie>
+</cookies>
+<headers>
+<header>
+<name>accept</name>
+<value>text/xml,application/xml,application/xhtml+xml,text/html;q=0.9,text/plain;q=0.8,image/png,*/*;q=0.5</value>
+</header>
+<header>
+<name>accept-charset</name>
+<value>UTF-8,*</value>
+</header>
+<header>
+<name>accept-encoding</name>
+<value>gzip,deflate</value>
+</header>
+<header>
+<name>accept-language</name>
+<value>en-us,en;q=0.5</value>
+</header>
+<header>
+<name>connection</name>
+<value>keep-alive</value>
+</header>
+<header>
+<name>cookie</name>
+<value>JSESSIONID=E07C1635C4C5C0250C2B98619EC403EC</value>
+</header>
+<header>
+<name>host</name>
+<value>localhost:8080</value>
+</header>
+<header>
+<name>keep-alive</name>
+<value>300</value>
+</header>
+<header>
+<name>referer</name>
+<value>http://localhost:8080/coreWeb/returnTo/pageWithJspInclude/page2.do</value>
+</header>
+<header>
+<name>user-agent</name>
+<value>Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.7) Gecko/20060909 Firefox/1.5.0.7</value>
+</header>
+</headers>
+</request>
+<response>
+<statusCode>200</statusCode>
+<reason></reason>
+<responseBody>
+<![CDATA[<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"
+	"http://www.w3.org/TR/html4/loose.dtd">
+<html lang="en">
+
+    <head>
+        <title>NavigateTo Current/Previous JSP with &lt;jsp:include&gt;</title>
+        <base href="http://localhost:8080/coreWeb/returnTo/pageWithJspInclude/page2.jsp">
+    </head>
+    <body>
+        <h3>NavigateTo Current/Previous JSP with &lt;jsp:include&gt;</h3>
+        <h3>Page2.jsp</h3>
+
+        <br/><br/>&quot;NavigateTo&quot; this page:
+        <a href="/coreWeb/returnTo/pageWithJspInclude/returnToPage.do">current...</a>
+
+        <br/><br/>&quot;NavigateTo&quot; the previous page:
+        <a href="/coreWeb/returnTo/pageWithJspInclude/returnToPrevPage.do">Prev...</a>
+
+        <br/><br/>Now, test &quot;NavigateTo&quot; this page (via shared flow):
+        <a href="/coreWeb/returnTo/pageWithJspInclude/shared.returnToPage.do">shared.curr</a>
+
+        <br/><br/>Now, test &quot;NavigateTo&quot; the previous page (via shared flow):
+        <a href="/coreWeb/returnTo/pageWithJspInclude/shared.returnToPrevPage.do">shared.prev</a>
+
+        <br/>
+        
+
+
+
+message = <span>in /returnTo/pageWithJspInclude/Controller.jpf.returnToPage()</span>
+
+
+
+    </body>
+
+</html>]]>
+</responseBody>
+</response>
+</test>
+<test>
+<testNumber>7</testNumber>
+<request>
+<protocol>HTTP</protocol>
+<protocolVersion>1.1</protocolVersion>
+<host>localhost</host>
+<port>8080</port>
+<uri>/coreWeb/returnTo/pageWithJspInclude/shared.returnToPage.do</uri>
+<method>GET</method>
+<parameters>
+</parameters>
+<cookies>
+<cookie>
+<name>JSESSIONID</name>
+<value>E07C1635C4C5C0250C2B98619EC403EC</value>
+</cookie>
+</cookies>
+<headers>
+<header>
+<name>accept</name>
+<value>text/xml,application/xml,application/xhtml+xml,text/html;q=0.9,text/plain;q=0.8,image/png,*/*;q=0.5</value>
+</header>
+<header>
+<name>accept-charset</name>
+<value>UTF-8,*</value>
+</header>
+<header>
+<name>accept-encoding</name>
+<value>gzip,deflate</value>
+</header>
+<header>
+<name>accept-language</name>
+<value>en-us,en;q=0.5</value>
+</header>
+<header>
+<name>connection</name>
+<value>keep-alive</value>
+</header>
+<header>
+<name>cookie</name>
+<value>JSESSIONID=E07C1635C4C5C0250C2B98619EC403EC</value>
+</header>
+<header>
+<name>host</name>
+<value>localhost:8080</value>
+</header>
+<header>
+<name>keep-alive</name>
+<value>300</value>
+</header>
+<header>
+<name>referer</name>
+<value>http://localhost:8080/coreWeb/returnTo/pageWithJspInclude/returnToPage.do</value>
+</header>
+<header>
+<name>user-agent</name>
+<value>Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.7) Gecko/20060909 Firefox/1.5.0.7</value>
+</header>
+</headers>
+</request>
+<response>
+<statusCode>200</statusCode>
+<reason></reason>
+<responseBody>
+<![CDATA[<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"
+	"http://www.w3.org/TR/html4/loose.dtd">
+<html lang="en">
+
+    <head>
+        <title>NavigateTo Current/Previous JSP with &lt;jsp:include&gt;</title>
+        <base href="http://localhost:8080/coreWeb/returnTo/pageWithJspInclude/page2.jsp">
+    </head>
+    <body>
+        <h3>NavigateTo Current/Previous JSP with &lt;jsp:include&gt;</h3>
+        <h3>Page2.jsp</h3>
+
+        <br/><br/>&quot;NavigateTo&quot; this page:
+        <a href="/coreWeb/returnTo/pageWithJspInclude/returnToPage.do">current...</a>
+
+        <br/><br/>&quot;NavigateTo&quot; the previous page:
+        <a href="/coreWeb/returnTo/pageWithJspInclude/returnToPrevPage.do">Prev...</a>
+
+        <br/><br/>Now, test &quot;NavigateTo&quot; this page (via shared flow):
+        <a href="/coreWeb/returnTo/pageWithJspInclude/shared.returnToPage.do">shared.curr</a>
+
+        <br/><br/>Now, test &quot;NavigateTo&quot; the previous page (via shared flow):
+        <a href="/coreWeb/returnTo/pageWithJspInclude/shared.returnToPrevPage.do">shared.prev</a>
+
+        <br/>
+        
+
+
+
+message = <span>in returnTo.pageWithJspInclude.SharedFlow.returnToPage()</span>
+
+
+
+    </body>
+
+</html>]]>
+</responseBody>
+</response>
+</test>
+<test>
+<testNumber>8</testNumber>
+<request>
+<protocol>HTTP</protocol>
+<protocolVersion>1.1</protocolVersion>
+<host>localhost</host>
+<port>8080</port>
+<uri>/coreWeb/returnTo/pageWithJspInclude/returnToPrevPage.do</uri>
+<method>GET</method>
+<parameters>
+</parameters>
+<cookies>
+<cookie>
+<name>JSESSIONID</name>
+<value>E07C1635C4C5C0250C2B98619EC403EC</value>
+</cookie>
+</cookies>
+<headers>
+<header>
+<name>accept</name>
+<value>text/xml,application/xml,application/xhtml+xml,text/html;q=0.9,text/plain;q=0.8,image/png,*/*;q=0.5</value>
+</header>
+<header>
+<name>accept-charset</name>
+<value>UTF-8,*</value>
+</header>
+<header>
+<name>accept-encoding</name>
+<value>gzip,deflate</value>
+</header>
+<header>
+<name>accept-language</name>
+<value>en-us,en;q=0.5</value>
+</header>
+<header>
+<name>connection</name>
+<value>keep-alive</value>
+</header>
+<header>
+<name>cookie</name>
+<value>JSESSIONID=E07C1635C4C5C0250C2B98619EC403EC</value>
+</header>
+<header>
+<name>host</name>
+<value>localhost:8080</value>
+</header>
+<header>
+<name>keep-alive</name>
+<value>300</value>
+</header>
+<header>
+<name>referer</name>
+<value>http://localhost:8080/coreWeb/returnTo/pageWithJspInclude/shared.returnToPage.do</value>
+</header>
+<header>
+<name>user-agent</name>
+<value>Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.7) Gecko/20060909 Firefox/1.5.0.7</value>
+</header>
+</headers>
+</request>
+<response>
+<statusCode>200</statusCode>
+<reason></reason>
+<responseBody>
+<![CDATA[<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"
+	"http://www.w3.org/TR/html4/loose.dtd">
+<html lang="en">
+
+    <head>
+        <title>NavigateTo Current/Previous JSP with &lt;jsp:include&gt;</title>
+        <base href="http://localhost:8080/coreWeb/returnTo/pageWithJspInclude/page1.jsp">
+    </head>
+    <body>
+        <h3>NavigateTo Current/Previous JSP with &lt;jsp:include&gt;</h3>
+        <h3>Page1.jsp</h3>
+
+        <p>
+            Tests the NavigateTo feature with a page containing a
+            &lt;jsp:include&gt; to make sure we don't set current page
+            info to the included page. (BEEHIVE-1115)
+        </p>
+
+        <br/><br/>&quot;NavigateTo&quot; this page:
+        <a href="/coreWeb/returnTo/pageWithJspInclude/returnToPage.do">current...</a>
+
+        <br/><br/>&quot;NavigateTo&quot; the previous page:
+        <a href="/coreWeb/returnTo/pageWithJspInclude/returnToPrevPage.do">Prev...</a>
+
+        <br/><br/>Now, test &quot;NavigateTo&quot; this page (via shared flow):
+        <a href="/coreWeb/returnTo/pageWithJspInclude/shared.returnToPage.do">shared.curr</a>
+
+        <br/><br/>Now, test &quot;NavigateTo&quot; the previous page (via shared flow):
+        <a href="/coreWeb/returnTo/pageWithJspInclude/shared.returnToPrevPage.do">shared.prev</a>
+
+        <br/>
+        
+
+
+
+message = <span>in /returnTo/pageWithJspInclude/Controller.jpf.returnToPrevPage()</span>
+
+
+
+
+        <br/><br/>go to
+        <a href="/coreWeb/returnTo/pageWithJspInclude/page2.do">page two...</a>
+    </body>
+
+</html>]]>
+</responseBody>
+</response>
+</test>
+<test>
+<testNumber>9</testNumber>
+<request>
+<protocol>HTTP</protocol>
+<protocolVersion>1.1</protocolVersion>
+<host>localhost</host>
+<port>8080</port>
+<uri>/coreWeb/returnTo/pageWithJspInclude/returnToPrevPage.do</uri>
+<method>GET</method>
+<parameters>
+</parameters>
+<cookies>
+<cookie>
+<name>JSESSIONID</name>
+<value>E07C1635C4C5C0250C2B98619EC403EC</value>
+</cookie>
+</cookies>
+<headers>
+<header>
+<name>accept</name>
+<value>text/xml,application/xml,application/xhtml+xml,text/html;q=0.9,text/plain;q=0.8,image/png,*/*;q=0.5</value>
+</header>
+<header>
+<name>accept-charset</name>
+<value>UTF-8,*</value>
+</header>
+<header>
+<name>accept-encoding</name>
+<value>gzip,deflate</value>
+</header>
+<header>
+<name>accept-language</name>
+<value>en-us,en;q=0.5</value>
+</header>
+<header>
+<name>connection</name>
+<value>keep-alive</value>
+</header>
+<header>
+<name>cookie</name>
+<value>JSESSIONID=E07C1635C4C5C0250C2B98619EC403EC</value>
+</header>
+<header>
+<name>host</name>
+<value>localhost:8080</value>
+</header>
+<header>
+<name>keep-alive</name>
+<value>300</value>
+</header>
+<header>
+<name>referer</name>
+<value>http://localhost:8080/coreWeb/returnTo/pageWithJspInclude/returnToPrevPage.do</value>
+</header>
+<header>
+<name>user-agent</name>
+<value>Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.7) Gecko/20060909 Firefox/1.5.0.7</value>
+</header>
+</headers>
+</request>
+<response>
+<statusCode>200</statusCode>
+<reason></reason>
+<responseBody>
+<![CDATA[<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"
+	"http://www.w3.org/TR/html4/loose.dtd">
+<html lang="en">
+
+    <head>
+        <title>NavigateTo Current/Previous JSP with &lt;jsp:include&gt;</title>
+        <base href="http://localhost:8080/coreWeb/returnTo/pageWithJspInclude/page2.jsp">
+    </head>
+    <body>
+        <h3>NavigateTo Current/Previous JSP with &lt;jsp:include&gt;</h3>
+        <h3>Page2.jsp</h3>
+
+        <br/><br/>&quot;NavigateTo&quot; this page:
+        <a href="/coreWeb/returnTo/pageWithJspInclude/returnToPage.do">current...</a>
+
+        <br/><br/>&quot;NavigateTo&quot; the previous page:
+        <a href="/coreWeb/returnTo/pageWithJspInclude/returnToPrevPage.do">Prev...</a>
+
+        <br/><br/>Now, test &quot;NavigateTo&quot; this page (via shared flow):
+        <a href="/coreWeb/returnTo/pageWithJspInclude/shared.returnToPage.do">shared.curr</a>
+
+        <br/><br/>Now, test &quot;NavigateTo&quot; the previous page (via shared flow):
+        <a href="/coreWeb/returnTo/pageWithJspInclude/shared.returnToPrevPage.do">shared.prev</a>
+
+        <br/>
+        
+
+
+
+message = <span>in /returnTo/pageWithJspInclude/Controller.jpf.returnToPrevPage()</span>
+
+
+
+    </body>
+
+</html>]]>
+</responseBody>
+</response>
+</test>
+<test>
+<testNumber>10</testNumber>
+<request>
+<protocol>HTTP</protocol>
+<protocolVersion>1.1</protocolVersion>
+<host>localhost</host>
+<port>8080</port>
+<uri>/coreWeb/returnTo/pageWithJspInclude/shared.returnToPrevPage.do</uri>
+<method>GET</method>
+<parameters>
+</parameters>
+<cookies>
+<cookie>
+<name>JSESSIONID</name>
+<value>E07C1635C4C5C0250C2B98619EC403EC</value>
+</cookie>
+</cookies>
+<headers>
+<header>
+<name>accept</name>
+<value>text/xml,application/xml,application/xhtml+xml,text/html;q=0.9,text/plain;q=0.8,image/png,*/*;q=0.5</value>
+</header>
+<header>
+<name>accept-charset</name>
+<value>UTF-8,*</value>
+</header>
+<header>
+<name>accept-encoding</name>
+<value>gzip,deflate</value>
+</header>
+<header>
+<name>accept-language</name>
+<value>en-us,en;q=0.5</value>
+</header>
+<header>
+<name>connection</name>
+<value>keep-alive</value>
+</header>
+<header>
+<name>cookie</name>
+<value>JSESSIONID=E07C1635C4C5C0250C2B98619EC403EC</value>
+</header>
+<header>
+<name>host</name>
+<value>localhost:8080</value>
+</header>
+<header>
+<name>keep-alive</name>
+<value>300</value>
+</header>
+<header>
+<name>referer</name>
+<value>http://localhost:8080/coreWeb/returnTo/pageWithJspInclude/returnToPrevPage.do</value>
+</header>
+<header>
+<name>user-agent</name>
+<value>Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.7) Gecko/20060909 Firefox/1.5.0.7</value>
+</header>
+</headers>
+</request>
+<response>
+<statusCode>200</statusCode>
+<reason></reason>
+<responseBody>
+<![CDATA[<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"
+	"http://www.w3.org/TR/html4/loose.dtd">
+<html lang="en">
+
+    <head>
+        <title>NavigateTo Current/Previous JSP with &lt;jsp:include&gt;</title>
+        <base href="http://localhost:8080/coreWeb/returnTo/pageWithJspInclude/page1.jsp">
+    </head>
+    <body>
+        <h3>NavigateTo Current/Previous JSP with &lt;jsp:include&gt;</h3>
+        <h3>Page1.jsp</h3>
+
+        <p>
+            Tests the NavigateTo feature with a page containing a
+            &lt;jsp:include&gt; to make sure we don't set current page
+            info to the included page. (BEEHIVE-1115)
+        </p>
+
+        <br/><br/>&quot;NavigateTo&quot; this page:
+        <a href="/coreWeb/returnTo/pageWithJspInclude/returnToPage.do">current...</a>
+
+        <br/><br/>&quot;NavigateTo&quot; the previous page:
+        <a href="/coreWeb/returnTo/pageWithJspInclude/returnToPrevPage.do">Prev...</a>
+
+        <br/><br/>Now, test &quot;NavigateTo&quot; this page (via shared flow):
+        <a href="/coreWeb/returnTo/pageWithJspInclude/shared.returnToPage.do">shared.curr</a>
+
+        <br/><br/>Now, test &quot;NavigateTo&quot; the previous page (via shared flow):
+        <a href="/coreWeb/returnTo/pageWithJspInclude/shared.returnToPrevPage.do">shared.prev</a>
+
+        <br/>
+        
+
+
+
+message = <span>in returnTo.pageWithJspInclude.SharedFlow.returnToPrevPage()</span>
+
+
+
+
+        <br/><br/>go to
+        <a href="/coreWeb/returnTo/pageWithJspInclude/page2.do">page two...</a>
+    </body>
+
+</html>]]>
+</responseBody>
+</response>
+</test>
+<test>
+<testNumber>11</testNumber>
+<request>
+<protocol>HTTP</protocol>
+<protocolVersion>1.1</protocolVersion>
+<host>localhost</host>
+<port>8080</port>
+<uri>/coreWeb/returnTo/pageWithJspInclude/shared.returnToPrevPage.do</uri>
+<method>GET</method>
+<parameters>
+</parameters>
+<cookies>
+<cookie>
+<name>JSESSIONID</name>
+<value>E07C1635C4C5C0250C2B98619EC403EC</value>
+</cookie>
+</cookies>
+<headers>
+<header>
+<name>accept</name>
+<value>text/xml,application/xml,application/xhtml+xml,text/html;q=0.9,text/plain;q=0.8,image/png,*/*;q=0.5</value>
+</header>
+<header>
+<name>accept-charset</name>
+<value>UTF-8,*</value>
+</header>
+<header>
+<name>accept-encoding</name>
+<value>gzip,deflate</value>
+</header>
+<header>
+<name>accept-language</name>
+<value>en-us,en;q=0.5</value>
+</header>
+<header>
+<name>connection</name>
+<value>keep-alive</value>
+</header>
+<header>
+<name>cookie</name>
+<value>JSESSIONID=E07C1635C4C5C0250C2B98619EC403EC</value>
+</header>
+<header>
+<name>host</name>
+<value>localhost:8080</value>
+</header>
+<header>
+<name>keep-alive</name>
+<value>300</value>
+</header>
+<header>
+<name>referer</name>
+<value>http://localhost:8080/coreWeb/returnTo/pageWithJspInclude/shared.returnToPrevPage.do</value>
+</header>
+<header>
+<name>user-agent</name>
+<value>Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.7) Gecko/20060909 Firefox/1.5.0.7</value>
+</header>
+</headers>
+</request>
+<response>
+<statusCode>200</statusCode>
+<reason></reason>
+<responseBody>
+<![CDATA[<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"
+	"http://www.w3.org/TR/html4/loose.dtd">
+<html lang="en">
+
+    <head>
+        <title>NavigateTo Current/Previous JSP with &lt;jsp:include&gt;</title>
+        <base href="http://localhost:8080/coreWeb/returnTo/pageWithJspInclude/page2.jsp">
+    </head>
+    <body>
+        <h3>NavigateTo Current/Previous JSP with &lt;jsp:include&gt;</h3>
+        <h3>Page2.jsp</h3>
+
+        <br/><br/>&quot;NavigateTo&quot; this page:
+        <a href="/coreWeb/returnTo/pageWithJspInclude/returnToPage.do">current...</a>
+
+        <br/><br/>&quot;NavigateTo&quot; the previous page:
+        <a href="/coreWeb/returnTo/pageWithJspInclude/returnToPrevPage.do">Prev...</a>
+
+        <br/><br/>Now, test &quot;NavigateTo&quot; this page (via shared flow):
+        <a href="/coreWeb/returnTo/pageWithJspInclude/shared.returnToPage.do">shared.curr</a>
+
+        <br/><br/>Now, test &quot;NavigateTo&quot; the previous page (via shared flow):
+        <a href="/coreWeb/returnTo/pageWithJspInclude/shared.returnToPrevPage.do">shared.prev</a>
+
+        <br/>
+        
+
+
+
+message = <span>in returnTo.pageWithJspInclude.SharedFlow.returnToPrevPage()</span>
+
+
+
+    </body>
+
+</html>]]>
+</responseBody>
+</response>
+</test>
+</tests>
+<endDate>08 Oct 2006, 04:02:14.421 PM MDT</endDate>
+<testCount>11</testCount>
+</recorderSession>

Propchange: beehive/trunk/netui/test/webapps/drt/testRecorder/tests/ReturnToWithInclude.xml
------------------------------------------------------------------------------
    svn:eol-style = native

Added: beehive/trunk/netui/test/webapps/drt/web/returnTo/pageWithJspInclude/index.jsp
URL: http://svn.apache.org/viewvc/beehive/trunk/netui/test/webapps/drt/web/returnTo/pageWithJspInclude/index.jsp?view=auto&rev=454228
==============================================================================
--- beehive/trunk/netui/test/webapps/drt/web/returnTo/pageWithJspInclude/index.jsp (added)
+++ beehive/trunk/netui/test/webapps/drt/web/returnTo/pageWithJspInclude/index.jsp Sun Oct  8 15:39:00 2006
@@ -0,0 +1,42 @@
+<%--
+   Licensed to the Apache Software Foundation (ASF) under one or more
+   contributor license agreements.  See the NOTICE file distributed with
+   this work for additional information regarding copyright ownership.
+   The ASF licenses this file to You under the Apache License, Version 2.0
+   (the "License"); you may not use this file except in compliance with
+   the License.  You may obtain a copy of the License at
+
+       http://www.apache.org/licenses/LICENSE-2.0
+
+   Unless required by applicable law or agreed to in writing, software
+   distributed under the License is distributed on an "AS IS" BASIS,
+   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+   See the License for the specific language governing permissions and
+   limitations under the License.
+
+   $Header:$
+--%>
+<%@ page language="java" contentType="text/html;charset=UTF-8"%>
+<%@ taglib prefix="netui" uri="http://beehive.apache.org/netui/tags-html-1.0"%>
+
+
+<netui:html>
+    <head>
+        <title>NavigateTo Current/Previous JSP with &lt;jsp:include&gt;</title>
+        <netui:base/>
+    </head>
+    <netui:body>
+        <h3>NavigateTo Current/Previous JSP with &lt;jsp:include&gt;</h3>
+        <p>
+            Tests the NavigateTo feature with a page containing a
+            &lt;jsp:include&gt; to make sure we don't set current page
+            info to the included page. (BEEHIVE-1115)
+        </p>
+        <br/>
+        <p>Start the test by going to the first JSP.</p>
+        <br/><br/>
+        <netui:anchor action="page1">page one...</netui:anchor>
+    </netui:body>
+</netui:html>
+
+  

Propchange: beehive/trunk/netui/test/webapps/drt/web/returnTo/pageWithJspInclude/index.jsp
------------------------------------------------------------------------------
    svn:eol-style = native

Added: beehive/trunk/netui/test/webapps/drt/web/returnTo/pageWithJspInclude/message.jsp
URL: http://svn.apache.org/viewvc/beehive/trunk/netui/test/webapps/drt/web/returnTo/pageWithJspInclude/message.jsp?view=auto&rev=454228
==============================================================================
--- beehive/trunk/netui/test/webapps/drt/web/returnTo/pageWithJspInclude/message.jsp (added)
+++ beehive/trunk/netui/test/webapps/drt/web/returnTo/pageWithJspInclude/message.jsp Sun Oct  8 15:39:00 2006
@@ -0,0 +1,24 @@
+<%--
+   Licensed to the Apache Software Foundation (ASF) under one or more
+   contributor license agreements.  See the NOTICE file distributed with
+   this work for additional information regarding copyright ownership.
+   The ASF licenses this file to You under the Apache License, Version 2.0
+   (the "License"); you may not use this file except in compliance with
+   the License.  You may obtain a copy of the License at
+
+       http://www.apache.org/licenses/LICENSE-2.0
+
+   Unless required by applicable law or agreed to in writing, software
+   distributed under the License is distributed on an "AS IS" BASIS,
+   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+   See the License for the specific language governing permissions and
+   limitations under the License.
+
+   $Header:$
+--%>
+<%@ page language="java" contentType="text/html;charset=UTF-8"%>
+<%@ taglib uri="http://beehive.apache.org/netui/tags-html-1.0" prefix="netui"%>
+
+message = <netui:span value="${pageInput.message}"/>
+
+

Propchange: beehive/trunk/netui/test/webapps/drt/web/returnTo/pageWithJspInclude/message.jsp
------------------------------------------------------------------------------
    svn:eol-style = native

Added: beehive/trunk/netui/test/webapps/drt/web/returnTo/pageWithJspInclude/page1.jsp
URL: http://svn.apache.org/viewvc/beehive/trunk/netui/test/webapps/drt/web/returnTo/pageWithJspInclude/page1.jsp?view=auto&rev=454228
==============================================================================
--- beehive/trunk/netui/test/webapps/drt/web/returnTo/pageWithJspInclude/page1.jsp (added)
+++ beehive/trunk/netui/test/webapps/drt/web/returnTo/pageWithJspInclude/page1.jsp Sun Oct  8 15:39:00 2006
@@ -0,0 +1,57 @@
+<%--
+   Licensed to the Apache Software Foundation (ASF) under one or more
+   contributor license agreements.  See the NOTICE file distributed with
+   this work for additional information regarding copyright ownership.
+   The ASF licenses this file to You under the Apache License, Version 2.0
+   (the "License"); you may not use this file except in compliance with
+   the License.  You may obtain a copy of the License at
+
+       http://www.apache.org/licenses/LICENSE-2.0
+
+   Unless required by applicable law or agreed to in writing, software
+   distributed under the License is distributed on an "AS IS" BASIS,
+   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+   See the License for the specific language governing permissions and
+   limitations under the License.
+
+   $Header:$
+--%>
+<%@ page language="java" contentType="text/html;charset=UTF-8"%>
+<%@ taglib prefix="netui" uri="http://beehive.apache.org/netui/tags-html-1.0"%>
+
+<netui:html>
+    <head>
+        <title>NavigateTo Current/Previous JSP with &lt;jsp:include&gt;</title>
+        <netui:base/>
+    </head>
+    <netui:body>
+        <h3>NavigateTo Current/Previous JSP with &lt;jsp:include&gt;</h3>
+        <h3>Page1.jsp</h3>
+
+        <p>
+            Tests the NavigateTo feature with a page containing a
+            &lt;jsp:include&gt; to make sure we don't set current page
+            info to the included page. (BEEHIVE-1115)
+        </p>
+
+        <br/><br/>&quot;NavigateTo&quot; this page:
+        <netui:anchor action="returnToPage">current...</netui:anchor>
+
+        <br/><br/>&quot;NavigateTo&quot; the previous page:
+        <netui:anchor action="returnToPrevPage">Prev...</netui:anchor>
+
+        <br/><br/>Now, test &quot;NavigateTo&quot; this page (via shared flow):
+        <netui:anchor action="shared.returnToPage">shared.curr</netui:anchor>
+
+        <br/><br/>Now, test &quot;NavigateTo&quot; the previous page (via shared flow):
+        <netui:anchor action="shared.returnToPrevPage">shared.prev</netui:anchor>
+
+        <br/>
+        <jsp:include page="message.jsp" />
+
+        <br/><br/>go to
+        <netui:anchor action="page2">page two...</netui:anchor>
+    </netui:body>
+</netui:html>
+
+  

Propchange: beehive/trunk/netui/test/webapps/drt/web/returnTo/pageWithJspInclude/page1.jsp
------------------------------------------------------------------------------
    svn:eol-style = native

Added: beehive/trunk/netui/test/webapps/drt/web/returnTo/pageWithJspInclude/page2.jsp
URL: http://svn.apache.org/viewvc/beehive/trunk/netui/test/webapps/drt/web/returnTo/pageWithJspInclude/page2.jsp?view=auto&rev=454228
==============================================================================
--- beehive/trunk/netui/test/webapps/drt/web/returnTo/pageWithJspInclude/page2.jsp (added)
+++ beehive/trunk/netui/test/webapps/drt/web/returnTo/pageWithJspInclude/page2.jsp Sun Oct  8 15:39:00 2006
@@ -0,0 +1,48 @@
+<%--
+   Licensed to the Apache Software Foundation (ASF) under one or more
+   contributor license agreements.  See the NOTICE file distributed with
+   this work for additional information regarding copyright ownership.
+   The ASF licenses this file to You under the Apache License, Version 2.0
+   (the "License"); you may not use this file except in compliance with
+   the License.  You may obtain a copy of the License at
+
+       http://www.apache.org/licenses/LICENSE-2.0
+
+   Unless required by applicable law or agreed to in writing, software
+   distributed under the License is distributed on an "AS IS" BASIS,
+   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+   See the License for the specific language governing permissions and
+   limitations under the License.
+
+   $Header:$
+--%>
+<%@ page language="java" contentType="text/html;charset=UTF-8"%>
+<%@ taglib prefix="netui" uri="http://beehive.apache.org/netui/tags-html-1.0"%>
+
+<netui:html>
+    <head>
+        <title>NavigateTo Current/Previous JSP with &lt;jsp:include&gt;</title>
+        <netui:base/>
+    </head>
+    <netui:body>
+        <h3>NavigateTo Current/Previous JSP with &lt;jsp:include&gt;</h3>
+        <h3>Page2.jsp</h3>
+
+        <br/><br/>&quot;NavigateTo&quot; this page:
+        <netui:anchor action="returnToPage">current...</netui:anchor>
+
+        <br/><br/>&quot;NavigateTo&quot; the previous page:
+        <netui:anchor action="returnToPrevPage">Prev...</netui:anchor>
+
+        <br/><br/>Now, test &quot;NavigateTo&quot; this page (via shared flow):
+        <netui:anchor action="shared.returnToPage">shared.curr</netui:anchor>
+
+        <br/><br/>Now, test &quot;NavigateTo&quot; the previous page (via shared flow):
+        <netui:anchor action="shared.returnToPrevPage">shared.prev</netui:anchor>
+
+        <br/>
+        <jsp:include page="message.jsp" />
+    </netui:body>
+</netui:html>
+
+  

Propchange: beehive/trunk/netui/test/webapps/drt/web/returnTo/pageWithJspInclude/page2.jsp
------------------------------------------------------------------------------
    svn:eol-style = native
--- beehive/trunk/netui/src/pageflow/org/apache/beehive/netui/pageflow/internal/DefaultActionForwardHandler.java (original)
+++ beehive/trunk/netui/src/pageflow/org/apache/beehive/netui/pageflow/internal/DefaultActionForwardHandler.java Sun Oct  8 15:39:00 2006
@@ -222,15 +222,19 @@
         }
         
         //
         // Save info on this forward for return-to="currentPage" or return-to="previousPage".  But, don't save
         // the info if the current forward is a return-to="currentPage" -- we don't want this to turn into
         // the page that's seen for *both* return-to="currentPage" and return-to="previousPage".
         //
-        if ( ! isReturnToCurrentPage )
-        {
-            flowController.savePreviousPageInfo( fwd, form, mapping, request, getServletContext(), isSpecialForward );
+        if (!isReturnToCurrentPage) {
+            flowController.savePreviousPageInfo(fwd, form, mapping, request, getServletContext(), isSpecialForward);
         }
-        
+        else {
+            request.setAttribute(InternalConstants.SAVED_PREVIOUS_PAGE_INFO_ATTR, Boolean.TRUE);
+        }
+
         return fwd;
     }
     
@@ -222,15 +222,19 @@
         
         //
-        // Save info on this forward for return-to="currentPage" or return-to="previousPage".  But, don't save
-        // the info if the current forward is a return-to="currentPage" -- we don't want this to turn into
-        // the page that's seen for *both* return-to="currentPage" and return-to="previousPage".
+        // Save info on this forward for return-to="currentPage" or return-to="previousPage".
+        // However, don't save the current forward as previous if this is a
+        // return-to="currentPage" -- we don't want this to turn into the page
+        // that's seen for *both* return-to="currentPage" and return-to="previousPage".
+        // Just set the request attribute indicating that prev page info state was saved.
         //

Modified: beehive/trunk/netui/src/pageflow/org/apache/beehive/netui/pageflow/internal/InternalConstants.java
URL: http://svn.apache.org/viewvc/beehive/trunk/netui/src/pageflow/org/apache/beehive/netui/pageflow/internal/InternalConstants.java?view=diff&rev=454228&r1=454227&r2=454228
==============================================================================